@@ -164,16 +164,14 @@ class ColumnConfig():
             raise TypeError(f"sql_alter {prev_sql_alter} must be a tuple, {type(prev_sql_alter)} given")
         if not isinstance(self.conf['sql_alter'], (tuple, list,)):
             raise TypeError(f"sql_alter {self.conf['sql_alter']} must be a tuple, {type(self.conf['sql_alter'])} given")
-        constraint = f'"__{table_name}_{self.conf["column_name"]}__"'
         query = ''
         msgs = []
         query_stubs = []
-        table = f'"{table_name}"'
-        column = f'"{self.conf["column_name"]}"'
+        column_name = self.conf["column_name"]
         for qs in self.conf['sql_alter']:
             if qs not in prev_sql_alter:
                 # new settings
-                qs = qs.format(table=table, column=column, constraint=constraint)
+                qs = qs.format(table=table_name, column=column_name)
                 query_stubs.append(qs)
                 msgs.append(f"\n* + {qs}")
 
@@ -200,30 +198,29 @@ class Field(object):
     Example sql_alter queries
 
     ```sql
-    ALTER TABLE {table} ALTER COLUMN {column} SET DEFAULT expression
-    ALTER TABLE {table} ALTER COLUMN {column} DROP DEFAULT
-    ALTER TABLE {table} ALTER COLUMN {column} SET NOT NULL
-    ALTER TABLE {table} ALTER COLUMN {column} SET STATISTICS integer
-    ALTER TABLE {table} ALTER COLUMN {column} SET ( attribute_option = value [, ... ] )
-    ALTER TABLE {table} ALTER COLUMN {column} RESET ( attribute_option [, ... ] )
-    ALTER TABLE {table} ALTER COLUMN {column} SET STORAGE { PLAIN | EXTERNAL | EXTENDED | MAIN }
+    ALTER TABLE "{table}" ALTER COLUMN "{column}" SET DEFAULT expression
+    ALTER TABLE "{table}" ALTER COLUMN "{column}" DROP DEFAULT
+    ALTER TABLE "{table}" ALTER COLUMN "{column}" SET NOT NULL
+    ALTER TABLE "{table}" ALTER COLUMN "{column}" SET STATISTICS integer
+    ALTER TABLE "{table}" ALTER COLUMN "{column}" SET ( attribute_option = value [, ... ] )
+    ALTER TABLE "{table}" ALTER COLUMN "{column}" RESET ( attribute_option [, ... ] )
+    ALTER TABLE "{table}" ALTER COLUMN "{column}" SET STORAGE { PLAIN | EXTERNAL | EXTENDED | MAIN }
     ```
 
-    {table}, {column}, and {constraint} will be replaced with quoted table name,
-    column name, and constraint_name respectively.
-
-    {constraint} = "__{table_name}_{column_name}__"
-
+    {table} and {column} will be replaced with table name,
+    and column name respectively.
 
 
     Args:
         sql_type (str): Data type in SQL.
         sql_onadd (str): sql to add in ADD clause after 'ADD COLUMN column_name data_type'
         sql_ondrop (str): Either 'RESTRICT' or 'CASCADE'.
-        sql_alter (Tuple[str]): Alter column queries; Example: ('ALTER TABLE {table} ALTER COLUMN {column} DROP DEFAULT',).
+        sql_alter (Tuple[str]): Alter column queries; Example: ('ALTER TABLE "{table}" ALTER COLUMN "{column}" DROP DEFAULT',).
         sql_engine (str): db engine, postgresql, mysql etc.. Defaults to 'postgresql'
         default (Any, optional): Pythonic default value (can be a callable). Defaults to Void. (Do not use mutable values, use function instead)
         value (Any, optional): Set a value that will prevail unless changed manually. Can be a function. Useful to make updated_at like fields.
+        choices (Tuple[Tuple[str, Any], ...], optional): choices tuple: (('Name of choice', 'value'), ...)
+        help_text (str, optional):  help text to describe this field.
         validator (callable, optional): A callable that accepts exactly one argument. Validates the value in `clean` method. Defaults to always_valid.
         modifier (callable, optional): A callable that accepts exactly one argument. Modifies the value if validation fails when the `clean` method is called.. Defaults to nomodify.
         fallback (bool, optional): Whether invalid value should fallback to default value suppressing exception. (May hide bugs in your program)
@@ -235,10 +232,19 @@ class Field(object):
                 sql_engine='postgresql',
                 default: Any=Void,
                 value: Any=Void,
+                unique=False,
+                choices: Tuple[Tuple[str, Any], ...] = (),
+                help_text: str = '',
                 validator: Callable=always_valid,
                 modifier: Callable=nomodify,
                 fallback=False,):
         self.sql_type = sql_type
+        unq_constraint = '__UNQ_{table}_{column}__'
+        if unique:
+            ualq = 'ALTER TABLE "{table}" ADD CONSTRAINT "%s" UNIQUE ("{column}");' % (unq_constraint,)
+        else:
+            ualq = 'ALTER TABLE "{table}" DROP CONSTRAINT IF EXISTS "%s";' % (unq_constraint,)
+        sql_alter = (ualq, *sql_alter)
         self.sql_conf = ColumnConfig(sql_type=sql_type, sql_onadd=sql_onadd, sql_ondrop=sql_ondrop, sql_alter=sql_alter, sql_engine=sql_engine)
         self.validator = validator
         self.modifier = modifier
@@ -252,6 +258,8 @@ class Field(object):
                 raise ValueError(f"Parameter 'value' and 'default' both can not be set at the same time.")
         else:
             self.default = default
+        self.choices = choices
+        self.help_text = help_text
 
 
     def __eq__(self, other: 'Field') -> bool: # type: ignore
@@ -338,7 +346,7 @@ class FieldValue():
     def __init__(self, field: Field):
         self._field = field
         self._value = Void
-        self._value_change_count = 0
+        self.value_change_count = 0
         self._ignore_first_change_count_ = False
 
     def __eq__(self, other):
@@ -351,7 +359,19 @@ class FieldValue():
         Returns:
             Any: value
         """
-        return self._value_change_count
+        return self.__value_change_count
+
+    @value_change_count.setter
+    def value_change_count(self, v: Any):
+        """Set value change counter
+
+        Args:
+            v (Any): value
+        """
+        if not self._field._is_perpetual_default:
+            self.__value_change_count = v
+        else:
+            self.__value_change_count = 1 # always change
 
     @property
     def value(self) -> Any:
@@ -360,7 +380,7 @@ class FieldValue():
         Returns:
             Any: value or default
         """
-        if self._value is Void or (self._field._is_perpetual_default and self._value_change_count == 0):
+        if self._value is Void or (self._field._is_perpetual_default and self.value_change_count == 0):
             return self._field.get_default()
         return self._value
 
@@ -384,7 +404,7 @@ class FieldValue():
         """
         self._value = self._field.clean(v, fallback=fallback)
         if not self._ignore_first_change_count_: # if from db, then value change count won't change
-            self._value_change_count = self._value_change_count + 1 # This must be the last line
+            self.value_change_count += 1 # This must be the last line
         self._ignore_first_change_count_ = False
         # when the clean method raises exception, it will not be counted as
         # a successful value assignment.
@@ -393,7 +413,7 @@ class FieldValue():
         """Return the value to its initial state.
         """
         self._value = Void
-        # must not change/decrease _value_change_count
+        # must not change/decrease value_change_count
         # when this value is set again, the counter should increase
         # according to its previous value.
         # delete itself is a change but it does not change the value
