@@ -103,9 +103,9 @@ class ModelType(type):
         # dict is ordered, officially from python 3.7
         for n, v in _class_.__dict__.items():
             if isinstance(v, Field):
-                if n.startswith('__') and n.endswith('__'):
+                if n.startswith('_') and n.endswith('_'):
                     raise AttributeError(f"Invalid field name '{n}' in model '{class_name}'. \
-                        Field name must not start and end with double underscore.")
+                        Field name must not start and end with underscore.")
                 if meta_attrs['proxy'] and n in attrs:
                     raise ValueError(f"Proxy model '{class_name}' can not define new field: {n}")
                 v.name = n
@@ -396,10 +396,13 @@ class ModelBase(metaclass=ModelType):
             v = fields[k].value
             if self.__class__._is_valid_down_(k, v):
                 return v
-            raise AttributeError(f'Invalid attempt to access field `{k}`. It is excluded using either exclude_fields_down or exclude_values_down in {self.__class__.__name__} Meta class')
+            raise AttributeError(f'Invalid attempt to access field `{k}`. It is excluded using either exclude_fields_down or exclude_values_down in {self.__class__.__name__} Meta class. Or it does not have any valid value.')
         raise AttributeError
 
-    def __setattr__(self, k, v):
+    def __setattr__(self, k: str, v):
+        if k.startswith('_') and k.endswith('_'):
+            self.__dict__[k] = v
+            return
         fields = self.Meta._fields_
         if k not in fields:
             raise AttributeError(f"No such field ('{k}') in model '{self.__class__.__name__}''")
@@ -410,8 +413,10 @@ class ModelBase(metaclass=ModelType):
                 fields[k]._ignore_first_change_count_ = True
                 self.Meta._fromdb_.remove(k)
             fields[k].value = v
+        elif k in self.Meta._fromdb_:
+            self.Meta._fromdb_.remove(k)
         else:
-            raise AttributeError(f'Can not set field `{k}`. It is excluded using either exclude_fields_up or exclude_values_up in {self.__class__.__name__} Meta class ')
+            raise AttributeError(f'Can not set field `{k}`. It is excluded using either exclude_fields_up or exclude_values_up in {self.__class__.__name__} Meta class. Or you are trying to set an invalid value: {v}')
 
     def __repr__(self):
         reprs = []
@@ -421,6 +426,91 @@ class ModelBase(metaclass=ModelType):
         return f'{self.__class__.__name__}({body})'
 
 
+    async def _pre_save_(self, db):
+        """Pre-save hook.
+
+        Override to run pre save cleanup.
+
+        Args:
+            db (DB): db handle.
+        """
+        pass
+
+    async def _pre_delete_(self, db):
+        """Pre-delete hook.
+
+        Override to run pre delete cleanup.
+
+        Args:
+            db (DB): db handle.
+        """
+        pass
+
+
+    async def _post_save_(self, db):
+        """Pre-save hook.
+
+        Override to run post save cleanup.
+
+        Args:
+            db (DB): db handle.
+        """
+        pass
+
+    async def _post_delete_(self, db):
+        """Pre-delete hook.
+
+        Override to run post delete cleanup.
+
+        Args:
+            db (DB): db handle.
+        """
+        pass
+
+
+
+    async def _pre_insert_(self, db):
+        """Pre-insert hook.
+
+        Override to run pre insert cleanup.
+
+        Args:
+            db (DB): db handle.
+        """
+        pass
+
+    async def _pre_update_(self, db):
+        """Pre-update hook.
+
+        Override to run pre update cleanup.
+
+        Args:
+            db (DB): db handle.
+        """
+        pass
+
+
+    async def _post_insert_(self, db):
+        """Pre-insert hook.
+
+        Override to run post insert cleanup.
+
+        Args:
+            db (DB): db handle.
+        """
+        pass
+
+    async def _post_update_(self, db):
+        """Pre-update hook.
+
+        Override to run post update cleanup.
+
+        Args:
+            db (DB): db handle.
+        """
+        pass
+
+
 
 class Model(ModelBase):
     """Base model to be inherited by other models.
